
/***************************************************************************
 * strcasecmp.c -- strcasecmp and strncasecmp for systems (like Windows)   *
 * which do not already have them.                                         *
 *                                                                         *
 ***********************IMPORTANT NMAP LICENSE TERMS************************
 *                                                                         *
 * The Nmap Security Scanner is (C) 1995-2003 Insecure.Com LLC. This       *
 * program is free software; you may redistribute and/or modify it under   *
 * the terms of the GNU General Public License as published by the Free    *
 * Software Foundation; Version 2.  This guarantees your right to use,     *
 * modify, and redistribute this software under certain conditions.  If    *
 * you wish to embed Nmap technology into proprietary software, we may be  *
 * willing to sell alternative licenses (contact sales@insecure.com).      *
 * Many security scanner vendors already license Nmap technology such as   *
 * our remote OS fingerprinting database and code.                         *
 *                                                                         *
 * Note that we consider aggregation/inclusion/integration of Nmap into an *
 * executable installer to constitute a derived work and thus subject to   *
 * the GPL restrictions.  We also consider certain programs that tightly   *
 * integrate with Nmap to constitute derivative works, even if they only   *
 * interface with Nmap by executing the Nmap binary and interpreting its   *
 * output rather than by direct linking.  If you are interested in         *
 * including Nmap with your proprietary software or appliance, please      *
 * contact us first to ensure proper licensing.                            *
 *                                                                         *
 * If you received these files with a written license agreement or         *
 * contract stating terms other than the (GPL) terms above, then that      *
 * alternative license agreement takes precedence over these comments.     *
 *                                                                         *
 * Source is provided to this software because we believe users have a     *
 * right to know exactly what a program is going to do before they run it. *
 * This also allows you to audit the software for security holes (none     *
 * have been found so far).                                                *
 *                                                                         *
 * Source code also allows you to port Nmap to new platforms, fix bugs,    *
 * and add new features.  You are highly encouraged to send your changes   *
 * to fyodor@insecure.org for possible incorporation into the main         *
 * distribution.  By sending these changes to Fyodor or one the            *
 * Insecure.Org development mailing lists, it is assumed that you are      *
 * offering Fyodor and Insecure.Com LLC the unlimited, non-exclusive right *
 * to reuse, modify, and relicense the code.  Nmap will always be          *
 * available Open Source, but this is important because the inability to   *
 * relicense code has caused devastating problems for other Free Software  *
 * projects (such as KDE and NASM).  We also occasionally relicense the    *
 * code to third parties as discussed above.  If you wish to specify       *
 * special license conditions of your contributions, just say so when you  *
 * send them.                                                              *
 *                                                                         *
 * This program is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
 * General Public License for more details at                              *
 * http://www.gnu.org/copyleft/gpl.html .                                  *
 *                                                                         *
 ***************************************************************************/

/* $Id: strcasecmp.c,v 1.6 2003/09/06 09:10:55 fyodor Exp $ */

#if !defined(HAVE_STRCASECMP) || !defined(HAVE_STRNCASECMP)
#include <stdlib.h>
#include <string.h>
#include "nbase.h"
#endif

#ifndef HAVE_STRCASECMP
int strcasecmp(const char *s1, const char *s2)
{
  int ret;
  
  char *cp1,*cp2;
  int i=0;
  
  cp1=malloc(strlen(s1)+1);
  memset(cp1,0,strlen(s1)+1);
  memcpy(cp1,s1,strlen(s1));
  for (i=0; cp1[i]>0; i++)
    {
      if ('a' <= cp1[i] && cp1[i] <= 'z')
	cp1[i] -= 32;
    }
  
  cp2=malloc(strlen(s2)+1);
  memset(cp2,0,strlen(s2)+1);
  memcpy(cp2,s2,strlen(s2));
  for (i=0; cp2[i]>0; i++)
    {
      if ('a' <= cp2[i] && cp2[i] <= 'z')
	cp2[i] -= 32;
    }

  ret=strcmp(cp1,cp2);
  
  free(cp1);
  free(cp2);
  return ret;
}
#endif

#ifndef HAVE_STRNCASECMP
int strncasecmp(const char *s1, const char *s2, size_t n)
{
  int ret;
  char *cp1,*cp2;
  int i=0;
  
  cp1= (char *) malloc(strlen(s1)+1);
  memset(cp1,0,strlen(s1)+1);
  memcpy(cp1,s1,strlen(s1));
  for (i=0; cp1[i]>0; i++)
    {
      if ('a' <= cp1[i] && cp1[i] <= 'z')
	cp1[i] -= 32;
    }
  
  cp2= (char *) malloc(strlen(s2)+1);
  memset(cp2,0,strlen(s2)+1);
  memcpy(cp2,s2,strlen(s2));
  for (i=0; cp2[i]>0; i++)
    {
      if ('a' <= cp2[i] && cp2[i] <= 'z')
	cp2[i] -= 32;
    }
  
  ret=strncmp(cp1,cp2,n);
  free(cp1);
  free(cp2);
  return ret;
}
#endif
